@@ -2,7 +2,7 @@ package App::perlimports::Include;
 
 use Moo;
 
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 
 use App::perlimports::ExportInspector ();
 use Class::Inspector                  ();
@@ -440,7 +440,7 @@ sub _build_formatted_ppi_statement {
     # of imports.
     if (   $self->_will_never_export
         || $self->_is_translatable
-        || ( $self->_has_explicit_exports && !@{ $self->_imports } ) ) {
+        || !@{ $self->_imports } ) {
         return $self->_maybe_get_new_include(
             sprintf(
                 'use %s %s();', $self->module_name,
@@ -451,15 +451,6 @@ sub _build_formatted_ppi_statement {
         );
     }
 
-    # We don't know if the module exports anything (because it may not be using
-    # Exporter) but we also haven't explicitly flagged this as a module which
-    # never exports. So basically we can't be correct with confidence, so we'll
-    # return the original statement.
-    if (  !$self->_has_explicit_exports
-        && $self->_include->type ne 'require' ) {
-        return $self->_include;
-    }
-
     my $statement;
 
     my @args = $self->_include->arguments;
@@ -669,7 +660,7 @@ App::perlimports::Include - Encapsulate one use statement in a document
 
 =head1 VERSION
 
-version 0.000017
+version 0.000018
 
 =head1 METHODS
 
